﻿using System;
using Microsoft.EntityFrameworkCore.Migrations;

#nullable disable

#pragma warning disable CA1814 // Prefer jagged arrays over multidimensional

namespace StubbedContextLib.Migrations
{
    /// <inheritdoc />
    public partial class MyMigrations : Migration
    {
        /// <inheritdoc />
        protected override void Up(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.CreateTable(
                name: "DataSource",
                columns: table => new
                {
                    IdSource = table.Column<int>(type: "INTEGER", nullable: false)
                        .Annotation("Sqlite:Autoincrement", true),
                    Type = table.Column<string>(type: "TEXT", maxLength: 100, nullable: false),
                    Model = table.Column<string>(type: "TEXT", maxLength: 100, nullable: false),
                    Precision = table.Column<float>(type: "REAL", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_DataSource", x => x.IdSource);
                });

            migrationBuilder.CreateTable(
                name: "Athlete",
                columns: table => new
                {
                    IdAthlete = table.Column<int>(type: "INTEGER", nullable: false)
                        .Annotation("Sqlite:Autoincrement", true),
                    Username = table.Column<string>(type: "TEXT", maxLength: 100, nullable: false),
                    LastName = table.Column<string>(type: "TEXT", maxLength: 100, nullable: false),
                    FirstName = table.Column<string>(type: "TEXT", maxLength: 150, nullable: false),
                    Email = table.Column<string>(type: "TEXT", maxLength: 100, nullable: false),
                    Sexe = table.Column<string>(type: "TEXT", maxLength: 1, nullable: false),
                    Length = table.Column<double>(type: "REAL", nullable: false),
                    Weight = table.Column<float>(type: "REAL", nullable: false),
                    Password = table.Column<string>(type: "TEXT", nullable: false),
                    DateOfBirth = table.Column<DateOnly>(type: "TEXT", nullable: false),
                    IsCoach = table.Column<bool>(type: "INTEGER", nullable: false),
                    ProfilPicture = table.Column<byte[]>(type: "BLOB", nullable: false),
                    DataSourceId = table.Column<int>(type: "INTEGER", nullable: true)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Athlete", x => x.IdAthlete);
                    table.ForeignKey(
                        name: "FK_Athlete_DataSource_DataSourceId",
                        column: x => x.DataSourceId,
                        principalTable: "DataSource",
                        principalColumn: "IdSource");
                });

            migrationBuilder.CreateTable(
                name: "Activity",
                columns: table => new
                {
                    IdActivity = table.Column<int>(type: "INTEGER", nullable: false)
                        .Annotation("Sqlite:Autoincrement", true),
                    Type = table.Column<string>(type: "TEXT", maxLength: 100, nullable: false),
                    Date = table.Column<DateOnly>(type: "TEXT", nullable: false),
                    StartTime = table.Column<TimeOnly>(type: "TEXT", nullable: false),
                    EndTime = table.Column<TimeOnly>(type: "TEXT", nullable: false),
                    EffortFelt = table.Column<int>(type: "INTEGER", nullable: false),
                    Variability = table.Column<float>(type: "REAL", nullable: false),
                    Variance = table.Column<float>(type: "REAL", nullable: false),
                    StandardDeviation = table.Column<float>(type: "REAL", nullable: false),
                    Average = table.Column<float>(type: "REAL", nullable: false),
                    Maximum = table.Column<int>(type: "INTEGER", nullable: false),
                    Minimum = table.Column<int>(type: "INTEGER", nullable: false),
                    AverageTemperature = table.Column<float>(type: "REAL", nullable: false),
                    HasAutoPause = table.Column<bool>(type: "INTEGER", nullable: false),
                    DataSourceId = table.Column<int>(type: "INTEGER", nullable: false),
                    AthleteId = table.Column<int>(type: "INTEGER", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Activity", x => x.IdActivity);
                    table.ForeignKey(
                        name: "FK_Activity_Athlete_AthleteId",
                        column: x => x.AthleteId,
                        principalTable: "Athlete",
                        principalColumn: "IdAthlete");
                    table.ForeignKey(
                        name: "FK_Activity_DataSource_DataSourceId",
                        column: x => x.DataSourceId,
                        principalTable: "DataSource",
                        principalColumn: "IdSource");
                });

            migrationBuilder.CreateTable(
                name: "FriendshipEntity",
                columns: table => new
                {
                    FollowingId = table.Column<int>(type: "INTEGER", nullable: false),
                    FollowerId = table.Column<int>(type: "INTEGER", nullable: false),
                    StartDate = table.Column<DateTime>(type: "TEXT", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_FriendshipEntity", x => new { x.FollowingId, x.FollowerId });
                    table.ForeignKey(
                        name: "FK_FriendshipEntity_Athlete_FollowerId",
                        column: x => x.FollowerId,
                        principalTable: "Athlete",
                        principalColumn: "IdAthlete",
                        onDelete: ReferentialAction.Cascade);
                    table.ForeignKey(
                        name: "FK_FriendshipEntity_Athlete_FollowingId",
                        column: x => x.FollowingId,
                        principalTable: "Athlete",
                        principalColumn: "IdAthlete",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "Notification",
                columns: table => new
                {
                    IdNotif = table.Column<int>(type: "INTEGER", nullable: false)
                        .Annotation("Sqlite:Autoincrement", true),
                    Message = table.Column<string>(type: "TEXT", maxLength: 100, nullable: false),
                    Date = table.Column<DateTime>(type: "TEXT", nullable: false),
                    Statut = table.Column<bool>(type: "INTEGER", nullable: false),
                    Urgence = table.Column<string>(type: "TEXT", maxLength: 100, nullable: false),
                    SenderId = table.Column<int>(type: "INTEGER", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Notification", x => x.IdNotif);
                    table.ForeignKey(
                        name: "FK_Notification_Athlete_SenderId",
                        column: x => x.SenderId,
                        principalTable: "Athlete",
                        principalColumn: "IdAthlete",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "Statistic",
                columns: table => new
                {
                    IdStatistic = table.Column<int>(type: "INTEGER", nullable: false)
                        .Annotation("Sqlite:Autoincrement", true),
                    Weight = table.Column<float>(type: "REAL", nullable: false),
                    AverageHeartRate = table.Column<double>(type: "REAL", nullable: false),
                    MaximumHeartRate = table.Column<double>(type: "REAL", nullable: false),
                    AverageCaloriesBurned = table.Column<double>(type: "REAL", nullable: false),
                    Date = table.Column<DateOnly>(type: "TEXT", nullable: false),
                    AthleteId = table.Column<int>(type: "INTEGER", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Statistic", x => x.IdStatistic);
                    table.ForeignKey(
                        name: "FK_Statistic_Athlete_AthleteId",
                        column: x => x.AthleteId,
                        principalTable: "Athlete",
                        principalColumn: "IdAthlete");
                });

            migrationBuilder.CreateTable(
                name: "Training",
                columns: table => new
                {
                    IdTraining = table.Column<int>(type: "INTEGER", nullable: false)
                        .Annotation("Sqlite:Autoincrement", true),
                    Date = table.Column<DateOnly>(type: "TEXT", nullable: false),
                    Description = table.Column<string>(type: "TEXT", maxLength: 300, nullable: true),
                    Latitude = table.Column<float>(type: "REAL", nullable: false),
                    Longitude = table.Column<float>(type: "REAL", nullable: false),
                    FeedBack = table.Column<string>(type: "TEXT", maxLength: 300, nullable: true),
                    CoachId = table.Column<int>(type: "INTEGER", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Training", x => x.IdTraining);
                    table.ForeignKey(
                        name: "FK_Training_Athlete_CoachId",
                        column: x => x.CoachId,
                        principalTable: "Athlete",
                        principalColumn: "IdAthlete",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "HeartRate",
                columns: table => new
                {
                    IdHeartRate = table.Column<int>(type: "INTEGER", nullable: false)
                        .Annotation("Sqlite:Autoincrement", true),
                    Altitude = table.Column<double>(type: "REAL", nullable: false),
                    Time = table.Column<TimeOnly>(type: "TEXT", nullable: false),
                    Temperature = table.Column<float>(type: "REAL", nullable: false),
                    Bpm = table.Column<int>(type: "INTEGER", nullable: false),
                    Longitude = table.Column<float>(type: "REAL", nullable: false),
                    Latitude = table.Column<float>(type: "REAL", nullable: false),
                    ActivityId = table.Column<int>(type: "INTEGER", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_HeartRate", x => x.IdHeartRate);
                    table.ForeignKey(
                        name: "FK_HeartRate_Activity_ActivityId",
                        column: x => x.ActivityId,
                        principalTable: "Activity",
                        principalColumn: "IdActivity",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "AthleteEntityNotificationEntity",
                columns: table => new
                {
                    NotificationsReceivedIdNotif = table.Column<int>(type: "INTEGER", nullable: false),
                    ReceiversIdAthlete = table.Column<int>(type: "INTEGER", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AthleteEntityNotificationEntity", x => new { x.NotificationsReceivedIdNotif, x.ReceiversIdAthlete });
                    table.ForeignKey(
                        name: "FK_AthleteEntityNotificationEntity_Athlete_ReceiversIdAthlete",
                        column: x => x.ReceiversIdAthlete,
                        principalTable: "Athlete",
                        principalColumn: "IdAthlete",
                        onDelete: ReferentialAction.Cascade);
                    table.ForeignKey(
                        name: "FK_AthleteEntityNotificationEntity_Notification_NotificationsReceivedIdNotif",
                        column: x => x.NotificationsReceivedIdNotif,
                        principalTable: "Notification",
                        principalColumn: "IdNotif",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "AthleteEntityTrainingEntity",
                columns: table => new
                {
                    AthletesIdAthlete = table.Column<int>(type: "INTEGER", nullable: false),
                    TrainingsAthleteIdTraining = table.Column<int>(type: "INTEGER", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AthleteEntityTrainingEntity", x => new { x.AthletesIdAthlete, x.TrainingsAthleteIdTraining });
                    table.ForeignKey(
                        name: "FK_AthleteEntityTrainingEntity_Athlete_AthletesIdAthlete",
                        column: x => x.AthletesIdAthlete,
                        principalTable: "Athlete",
                        principalColumn: "IdAthlete",
                        onDelete: ReferentialAction.Cascade);
                    table.ForeignKey(
                        name: "FK_AthleteEntityTrainingEntity_Training_TrainingsAthleteIdTraining",
                        column: x => x.TrainingsAthleteIdTraining,
                        principalTable: "Training",
                        principalColumn: "IdTraining",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.InsertData(
                table: "Athlete",
                columns: new[] { "IdAthlete", "DataSourceId", "DateOfBirth", "Email", "FirstName", "IsCoach", "LastName", "Length", "Password", "ProfilPicture", "Sexe", "Username", "Weight" },
                values: new object[,]
                {
                    { 1, null, new DateOnly(1990, 1, 1), "john.doe@example.com", "John", true, "Doe", 1.8, "password123", new byte[] { 34, 85, 107, 108, 71, 82, 116, 119, 68, 65, 65, 66, 88, 82, 85, 74, 81, 86, 108, 65, 52, 73, 78, 65, 68, 65, 65, 65, 119, 69, 65, 67, 100, 65, 83, 111, 113, 65, 67, 111, 65, 65, 77, 65, 83, 74, 90, 103, 67, 100, 77, 111, 83, 67, 122, 54, 53, 53, 110, 100, 85, 52, 88, 88, 65, 80, 50, 121, 88, 73, 103, 101, 53, 110, 101, 77, 47, 81, 100, 54, 87, 67, 102, 79, 56, 101, 118, 111, 106, 50, 83, 48, 65, 47, 112, 55, 43, 102, 48, 65, 110, 56, 53, 99, 66, 120, 108, 76, 68, 103, 80, 67, 56, 106, 79, 47, 48, 110, 115, 108, 47, 49, 51, 47, 79, 56, 118, 118, 122, 106, 55, 65, 102, 56, 115, 47, 112, 51, 47, 72, 52, 70, 85, 54, 116, 100, 52, 77, 67, 119, 113, 50, 51, 122, 49, 72, 50, 117, 122, 111, 75, 73, 88, 97, 113, 74, 110, 105, 80, 73, 47, 98, 82, 77, 102, 56, 113, 122, 118, 48, 90, 112, 43, 72, 69, 49, 82, 67, 66, 119, 53, 87, 81, 49, 106, 47, 74, 111, 118, 100, 77, 49, 70, 83, 53, 50, 43, 81, 99, 97, 65, 65, 65, 47, 118, 47, 43, 78, 120, 85, 52, 68, 112, 80, 107, 51, 43, 120, 81, 80, 87, 55, 116, 99, 109, 85, 82, 83, 111, 57, 118, 67, 52, 113, 99, 43, 88, 77, 120, 78, 86, 66, 122, 69, 77, 53, 69, 56, 97, 99, 116, 68, 122, 57, 56, 103, 109, 119, 84, 88, 103, 68, 54, 50, 101, 57, 69, 109, 71, 47, 101, 114, 118, 100, 100, 50, 111, 118, 70, 70, 83, 117, 120, 89, 112, 112, 87, 108, 47, 119, 116, 97, 88, 51, 114, 107, 110, 48, 120, 114, 116, 56, 113, 79, 113, 108, 47, 53, 73, 50, 106, 102, 76, 79, 110, 67, 85, 48, 107, 65, 76, 76, 99, 87, 52, 70, 47, 119, 84, 106, 85, 49, 48, 113, 115, 120, 90, 88, 87, 57, 102, 120, 97, 117, 67, 54, 79, 80, 86, 82, 70, 50, 56, 115, 99, 57, 52, 86, 57, 111, 99, 109, 111, 83, 87, 121, 43, 115, 102, 54, 106, 87, 51, 118, 89, 107, 86, 79, 104, 43, 103, 69, 47, 82, 69, 48, 76, 54, 98, 50, 100, 51, 111, 70, 121, 72, 109, 107, 82, 74, 110, 102, 89, 119, 71, 56, 111, 51, 112, 54, 102, 118, 57, 112, 105, 118, 78, 70, 53, 97, 111, 112, 73, 66, 122, 70, 110, 106, 122, 119, 98, 47, 86, 113, 83, 113, 51, 47, 98, 43, 77, 87, 75, 70, 109, 106, 114, 56, 84, 49, 113, 101, 52, 47, 102, 73, 84, 111, 50, 118, 66, 87, 69, 113, 68, 121, 111, 103, 86, 51, 90, 86, 71, 110, 68, 86, 105, 50, 68, 98, 105, 69, 70, 86, 83, 85, 114, 50, 101, 88, 84, 78, 90, 81, 57, 86, 47, 68, 57, 81, 67, 47, 43, 118, 67, 82, 53, 84, 71, 121, 88, 57, 81, 79, 86, 66, 103, 116, 65, 89, 116, 109, 47, 90, 84, 73, 119, 122, 80, 69, 89, 66, 57, 78, 114, 86, 49, 78, 101, 79, 49, 47, 115, 65, 122, 55, 56, 117, 48, 116, 87, 53, 57, 114, 48, 73, 43, 83, 79, 53, 74, 103, 109, 51, 66, 57, 105, 49, 116, 111, 82, 117, 114, 122, 72, 118, 57, 69, 90, 74, 57, 121, 90, 76, 56, 110, 97, 102, 98, 47, 84, 49, 70, 97, 111, 80, 68, 107, 117, 74, 102, 77, 43, 105, 80, 115, 48, 106, 56, 120, 110, 83, 55, 84, 97, 85, 47, 103, 69, 75, 48, 119, 67, 120, 101, 68, 89, 82, 89, 116, 74, 120, 57, 106, 52, 104, 85, 81, 113, 55, 112, 65, 117, 47, 84, 50, 121, 87, 121, 48, 118, 106, 99, 85, 72, 107, 105, 57, 53, 50, 90, 78, 98, 88, 110, 88, 120, 66, 56, 109, 56, 112, 86, 53, 120, 57, 69, 49, 115, 102, 76, 106, 53, 77, 90, 69, 103, 112, 85, 50, 88, 86, 56, 82, 72, 114, 86, 118, 87, 110, 105, 67, 106, 115, 102, 54, 118, 103, 120, 109, 82, 55, 43, 75, 116, 119, 73, 98, 77, 106, 97, 104, 105, 116, 85, 71, 116, 72, 101, 116, 49, 87, 100, 76, 43, 56, 77, 109, 100, 76, 50, 57, 105, 81, 74, 67, 51, 55, 112, 68, 88, 105, 114, 105, 114, 49, 78, 105, 98, 120, 75, 75, 104, 70, 89, 82, 117, 74, 51, 120, 87, 57, 79, 48, 114, 57, 43, 86, 110, 104, 56, 100, 105, 113, 98, 66, 117, 88, 113, 68, 98, 89, 82, 47, 77, 83, 111, 72, 118, 115, 99, 79, 67, 109, 50, 116, 57, 53, 100, 78, 53, 87, 66, 100, 82, 85, 111, 68, 55, 89, 67, 71, 47, 90, 72, 87, 99, 55, 89, 112, 118, 47, 120, 47, 97, 108, 52, 102, 107, 66, 50, 108, 90, 108, 89, 104, 86, 87, 72, 120, 106, 97, 111, 101, 70, 57, 106, 69, 80, 73, 48, 103, 65, 78, 53, 88, 115, 118, 85, 73, 54, 104, 98, 122, 69, 122, 87, 77, 115, 78, 87, 47, 49, 111, 114, 107, 78, 79, 110, 108, 115, 107, 97, 108, 103, 109, 112, 73, 52, 66, 50, 114, 109, 52, 71, 99, 55, 76, 78, 117, 105, 43, 77, 117, 77, 66, 114, 112, 110, 66, 118, 76, 107, 98, 89, 88, 57, 101, 120, 101, 57, 103, 56, 116, 117, 55, 119, 76, 116, 55, 83, 99, 79, 106, 68, 99, 76, 57, 57, 111, 79, 121, 82, 56, 57, 77, 104, 57, 76, 56, 114, 100, 52, 43, 52, 51, 43, 74, 81, 121, 82, 54, 116, 115, 73, 102, 99, 80, 74, 111, 54, 84, 54, 70, 120, 72, 102, 49, 49, 100, 47, 77, 71, 97, 121, 74, 105, 43, 83, 87, 99, 116, 47, 117, 104, 118, 118, 117, 97, 48, 111, 79, 104, 43, 122, 88, 78, 73, 97, 85, 122, 103, 111, 66, 109, 117, 49, 88, 85, 76, 106, 107, 112, 117, 65, 48, 71, 104, 122, 99, 116, 102, 51, 48, 106, 98, 89, 49, 65, 79, 77, 52, 57, 113, 98, 77, 90, 82, 89, 83, 57, 65, 43, 48, 83, 49, 72, 114, 72, 80, 110, 119, 82, 118, 112, 81, 89, 47, 83, 106, 52, 120, 75, 80, 110, 48, 103, 100, 112, 118, 47, 43, 105, 84, 98, 75, 74, 98, 56, 122, 107, 80, 67, 52, 47, 57, 97, 102, 48, 74, 118, 101, 115, 97, 43, 71, 68, 71, 48, 47, 105, 119, 51, 84, 115, 119, 101, 110, 77, 104, 113, 108, 104, 55, 66, 77, 57, 77, 87, 53, 116, 120, 112, 101, 98, 108, 115, 66, 121, 120, 52, 87, 110, 74, 47, 111, 72, 118, 54, 99, 99, 48, 100, 109, 77, 55, 116, 115, 86, 51, 54, 108, 89, 107, 67, 84, 85, 88, 69, 102, 47, 48, 101, 75, 108, 110, 102, 105, 118, 110, 78, 48, 103, 49, 103, 43, 106, 47, 76, 107, 57, 101, 116, 47, 117, 111, 97, 54, 84, 70, 67, 87, 48, 72, 103, 119, 70, 79, 73, 86, 70, 117, 109, 69, 89, 100, 84, 54, 55, 53, 80, 102, 117, 84, 114, 89, 79, 53, 111, 56, 90, 114, 87, 69, 73, 72, 116, 118, 50, 67, 116, 108, 114, 118, 57, 74, 51, 84, 114, 115, 108, 68, 47, 105, 75, 69, 119, 116, 105, 112, 71, 72, 116, 110, 48, 86, 97, 107, 56, 66, 57, 119, 76, 76, 43, 107, 122, 43, 67, 73, 81, 47, 86, 71, 52, 75, 74, 112, 88, 106, 120, 56, 56, 67, 101, 67, 67, 52, 88, 97, 71, 105, 116, 69, 100, 106, 65, 65, 65, 34 }, "M", "Doe", 75f },
                    { 3, null, new DateOnly(1992, 1, 1), "paul.martin@example.com", "Paul", true, "Martin", 1.75, "super789", new byte[] { 34, 85, 107, 108, 71, 82, 116, 119, 68, 65, 65, 66, 88, 82, 85, 74, 81, 86, 108, 65, 52, 73, 78, 65, 68, 65, 65, 65, 119, 69, 65, 67, 100, 65, 83, 111, 113, 65, 67, 111, 65, 65, 77, 65, 83, 74, 90, 103, 67, 100, 77, 111, 83, 67, 122, 54, 53, 53, 110, 100, 85, 52, 88, 88, 65, 80, 50, 121, 88, 73, 103, 101, 53, 110, 101, 77, 47, 81, 100, 54, 87, 67, 102, 79, 56, 101, 118, 111, 106, 50, 83, 48, 65, 47, 112, 55, 43, 102, 48, 65, 110, 56, 53, 99, 66, 120, 108, 76, 68, 103, 80, 67, 56, 106, 79, 47, 48, 110, 115, 108, 47, 49, 51, 47, 79, 56, 118, 118, 122, 106, 55, 65, 102, 56, 115, 47, 112, 51, 47, 72, 52, 70, 85, 54, 116, 100, 52, 77, 67, 119, 113, 50, 51, 122, 49, 72, 50, 117, 122, 111, 75, 73, 88, 97, 113, 74, 110, 105, 80, 73, 47, 98, 82, 77, 102, 56, 113, 122, 118, 48, 90, 112, 43, 72, 69, 49, 82, 67, 66, 119, 53, 87, 81, 49, 106, 47, 74, 111, 118, 100, 77, 49, 70, 83, 53, 50, 43, 81, 99, 97, 65, 65, 65, 47, 118, 47, 43, 78, 120, 85, 52, 68, 112, 80, 107, 51, 43, 120, 81, 80, 87, 55, 116, 99, 109, 85, 82, 83, 111, 57, 118, 67, 52, 113, 99, 43, 88, 77, 120, 78, 86, 66, 122, 69, 77, 53, 69, 56, 97, 99, 116, 68, 122, 57, 56, 103, 109, 119, 84, 88, 103, 68, 54, 50, 101, 57, 69, 109, 71, 47, 101, 114, 118, 100, 100, 50, 111, 118, 70, 70, 83, 117, 120, 89, 112, 112, 87, 108, 47, 119, 116, 97, 88, 51, 114, 107, 110, 48, 120, 114, 116, 56, 113, 79, 113, 108, 47, 53, 73, 50, 106, 102, 76, 79, 110, 67, 85, 48, 107, 65, 76, 76, 99, 87, 52, 70, 47, 119, 84, 106, 85, 49, 48, 113, 115, 120, 90, 88, 87, 57, 102, 120, 97, 117, 67, 54, 79, 80, 86, 82, 70, 50, 56, 115, 99, 57, 52, 86, 57, 111, 99, 109, 111, 83, 87, 121, 43, 115, 102, 54, 106, 87, 51, 118, 89, 107, 86, 79, 104, 43, 103, 69, 47, 82, 69, 48, 76, 54, 98, 50, 100, 51, 111, 70, 121, 72, 109, 107, 82, 74, 110, 102, 89, 119, 71, 56, 111, 51, 112, 54, 102, 118, 57, 112, 105, 118, 78, 70, 53, 97, 111, 112, 73, 66, 122, 70, 110, 106, 122, 119, 98, 47, 86, 113, 83, 113, 51, 47, 98, 43, 77, 87, 75, 70, 109, 106, 114, 56, 84, 49, 113, 101, 52, 47, 102, 73, 84, 111, 50, 118, 66, 87, 69, 113, 68, 121, 111, 103, 86, 51, 90, 86, 71, 110, 68, 86, 105, 50, 68, 98, 105, 69, 70, 86, 83, 85, 114, 50, 101, 88, 84, 78, 90, 81, 57, 86, 47, 68, 57, 81, 67, 47, 43, 118, 67, 82, 53, 84, 71, 121, 88, 57, 81, 79, 86, 66, 103, 116, 65, 89, 116, 109, 47, 90, 84, 73, 119, 122, 80, 69, 89, 66, 57, 78, 114, 86, 49, 78, 101, 79, 49, 47, 115, 65, 122, 55, 56, 117, 48, 116, 87, 53, 57, 114, 48, 73, 43, 83, 79, 53, 74, 103, 109, 51, 66, 57, 105, 49, 116, 111, 82, 117, 114, 122, 72, 118, 57, 69, 90, 74, 57, 121, 90, 76, 56, 110, 97, 102, 98, 47, 84, 49, 70, 97, 111, 80, 68, 107, 117, 74, 102, 77, 43, 105, 80, 115, 48, 106, 56, 120, 110, 83, 55, 84, 97, 85, 47, 103, 69, 75, 48, 119, 67, 120, 101, 68, 89, 82, 89, 116, 74, 120, 57, 106, 52, 104, 85, 81, 113, 55, 112, 65, 117, 47, 84, 50, 121, 87, 121, 48, 118, 106, 99, 85, 72, 107, 105, 57, 53, 50, 90, 78, 98, 88, 110, 88, 120, 66, 56, 109, 56, 112, 86, 53, 120, 57, 69, 49, 115, 102, 76, 106, 53, 77, 90, 69, 103, 112, 85, 50, 88, 86, 56, 82, 72, 114, 86, 118, 87, 110, 105, 67, 106, 115, 102, 54, 118, 103, 120, 109, 82, 55, 43, 75, 116, 119, 73, 98, 77, 106, 97, 104, 105, 116, 85, 71, 116, 72, 101, 116, 49, 87, 100, 76, 43, 56, 77, 109, 100, 76, 50, 57, 105, 81, 74, 67, 51, 55, 112, 68, 88, 105, 114, 105, 114, 49, 78, 105, 98, 120, 75, 75, 104, 70, 89, 82, 117, 74, 51, 120, 87, 57, 79, 48, 114, 57, 43, 86, 110, 104, 56, 100, 105, 113, 98, 66, 117, 88, 113, 68, 98, 89, 82, 47, 77, 83, 111, 72, 118, 115, 99, 79, 67, 109, 50, 116, 57, 53, 100, 78, 53, 87, 66, 100, 82, 85, 111, 68, 55, 89, 67, 71, 47, 90, 72, 87, 99, 55, 89, 112, 118, 47, 120, 47, 97, 108, 52, 102, 107, 66, 50, 108, 90, 108, 89, 104, 86, 87, 72, 120, 106, 97, 111, 101, 70, 57, 106, 69, 80, 73, 48, 103, 65, 78, 53, 88, 115, 118, 85, 73, 54, 104, 98, 122, 69, 122, 87, 77, 115, 78, 87, 47, 49, 111, 114, 107, 78, 79, 110, 108, 115, 107, 97, 108, 103, 109, 112, 73, 52, 66, 50, 114, 109, 52, 71, 99, 55, 76, 78, 117, 105, 43, 77, 117, 77, 66, 114, 112, 110, 66, 118, 76, 107, 98, 89, 88, 57, 101, 120, 101, 57, 103, 56, 116, 117, 55, 119, 76, 116, 55, 83, 99, 79, 106, 68, 99, 76, 57, 57, 111, 79, 121, 82, 56, 57, 77, 104, 57, 76, 56, 114, 100, 52, 43, 52, 51, 43, 74, 81, 121, 82, 54, 116, 115, 73, 102, 99, 80, 74, 111, 54, 84, 54, 70, 120, 72, 102, 49, 49, 100, 47, 77, 71, 97, 121, 74, 105, 43, 83, 87, 99, 116, 47, 117, 104, 118, 118, 117, 97, 48, 111, 79, 104, 43, 122, 88, 78, 73, 97, 85, 122, 103, 111, 66, 109, 117, 49, 88, 85, 76, 106, 107, 112, 117, 65, 48, 71, 104, 122, 99, 116, 102, 51, 48, 106, 98, 89, 49, 65, 79, 77, 52, 57, 113, 98, 77, 90, 82, 89, 83, 57, 65, 43, 48, 83, 49, 72, 114, 72, 80, 110, 119, 82, 118, 112, 81, 89, 47, 83, 106, 52, 120, 75, 80, 110, 48, 103, 100, 112, 118, 47, 43, 105, 84, 98, 75, 74, 98, 56, 122, 107, 80, 67, 52, 47, 57, 97, 102, 48, 74, 118, 101, 115, 97, 43, 71, 68, 71, 48, 47, 105, 119, 51, 84, 115, 119, 101, 110, 77, 104, 113, 108, 104, 55, 66, 77, 57, 77, 87, 53, 116, 120, 112, 101, 98, 108, 115, 66, 121, 120, 52, 87, 110, 74, 47, 111, 72, 118, 54, 99, 99, 48, 100, 109, 77, 55, 116, 115, 86, 51, 54, 108, 89, 107, 67, 84, 85, 88, 69, 102, 47, 48, 101, 75, 108, 110, 102, 105, 118, 110, 78, 48, 103, 49, 103, 43, 106, 47, 76, 107, 57, 101, 116, 47, 117, 111, 97, 54, 84, 70, 67, 87, 48, 72, 103, 119, 70, 79, 73, 86, 70, 117, 109, 69, 89, 100, 84, 54, 55, 53, 80, 102, 117, 84, 114, 89, 79, 53, 111, 56, 90, 114, 87, 69, 73, 72, 116, 118, 50, 67, 116, 108, 114, 118, 57, 74, 51, 84, 114, 115, 108, 68, 47, 105, 75, 69, 119, 116, 105, 112, 71, 72, 116, 110, 48, 86, 97, 107, 56, 66, 57, 119, 76, 76, 43, 107, 122, 43, 67, 73, 81, 47, 86, 71, 52, 75, 74, 112, 88, 106, 120, 56, 56, 67, 101, 67, 67, 52, 88, 97, 71, 105, 116, 69, 100, 106, 65, 65, 65, 34 }, "M", "Martin", 68f },
                    { 4, null, new DateOnly(1993, 1, 1), "anna.brown@example.com", "Anna", false, "Brown", 1.7, "test000", new byte[] { 34, 85, 107, 108, 71, 82, 116, 119, 68, 65, 65, 66, 88, 82, 85, 74, 81, 86, 108, 65, 52, 73, 78, 65, 68, 65, 65, 65, 119, 69, 65, 67, 100, 65, 83, 111, 113, 65, 67, 111, 65, 65, 77, 65, 83, 74, 90, 103, 67, 100, 77, 111, 83, 67, 122, 54, 53, 53, 110, 100, 85, 52, 88, 88, 65, 80, 50, 121, 88, 73, 103, 101, 53, 110, 101, 77, 47, 81, 100, 54, 87, 67, 102, 79, 56, 101, 118, 111, 106, 50, 83, 48, 65, 47, 112, 55, 43, 102, 48, 65, 110, 56, 53, 99, 66, 120, 108, 76, 68, 103, 80, 67, 56, 106, 79, 47, 48, 110, 115, 108, 47, 49, 51, 47, 79, 56, 118, 118, 122, 106, 55, 65, 102, 56, 115, 47, 112, 51, 47, 72, 52, 70, 85, 54, 116, 100, 52, 77, 67, 119, 113, 50, 51, 122, 49, 72, 50, 117, 122, 111, 75, 73, 88, 97, 113, 74, 110, 105, 80, 73, 47, 98, 82, 77, 102, 56, 113, 122, 118, 48, 90, 112, 43, 72, 69, 49, 82, 67, 66, 119, 53, 87, 81, 49, 106, 47, 74, 111, 118, 100, 77, 49, 70, 83, 53, 50, 43, 81, 99, 97, 65, 65, 65, 47, 118, 47, 43, 78, 120, 85, 52, 68, 112, 80, 107, 51, 43, 120, 81, 80, 87, 55, 116, 99, 109, 85, 82, 83, 111, 57, 118, 67, 52, 113, 99, 43, 88, 77, 120, 78, 86, 66, 122, 69, 77, 53, 69, 56, 97, 99, 116, 68, 122, 57, 56, 103, 109, 119, 84, 88, 103, 68, 54, 50, 101, 57, 69, 109, 71, 47, 101, 114, 118, 100, 100, 50, 111, 118, 70, 70, 83, 117, 120, 89, 112, 112, 87, 108, 47, 119, 116, 97, 88, 51, 114, 107, 110, 48, 120, 114, 116, 56, 113, 79, 113, 108, 47, 53, 73, 50, 106, 102, 76, 79, 110, 67, 85, 48, 107, 65, 76, 76, 99, 87, 52, 70, 47, 119, 84, 106, 85, 49, 48, 113, 115, 120, 90, 88, 87, 57, 102, 120, 97, 117, 67, 54, 79, 80, 86, 82, 70, 50, 56, 115, 99, 57, 52, 86, 57, 111, 99, 109, 111, 83, 87, 121, 43, 115, 102, 54, 106, 87, 51, 118, 89, 107, 86, 79, 104, 43, 103, 69, 47, 82, 69, 48, 76, 54, 98, 50, 100, 51, 111, 70, 121, 72, 109, 107, 82, 74, 110, 102, 89, 119, 71, 56, 111, 51, 112, 54, 102, 118, 57, 112, 105, 118, 78, 70, 53, 97, 111, 112, 73, 66, 122, 70, 110, 106, 122, 119, 98, 47, 86, 113, 83, 113, 51, 47, 98, 43, 77, 87, 75, 70, 109, 106, 114, 56, 84, 49, 113, 101, 52, 47, 102, 73, 84, 111, 50, 118, 66, 87, 69, 113, 68, 121, 111, 103, 86, 51, 90, 86, 71, 110, 68, 86, 105, 50, 68, 98, 105, 69, 70, 86, 83, 85, 114, 50, 101, 88, 84, 78, 90, 81, 57, 86, 47, 68, 57, 81, 67, 47, 43, 118, 67, 82, 53, 84, 71, 121, 88, 57, 81, 79, 86, 66, 103, 116, 65, 89, 116, 109, 47, 90, 84, 73, 119, 122, 80, 69, 89, 66, 57, 78, 114, 86, 49, 78, 101, 79, 49, 47, 115, 65, 122, 55, 56, 117, 48, 116, 87, 53, 57, 114, 48, 73, 43, 83, 79, 53, 74, 103, 109, 51, 66, 57, 105, 49, 116, 111, 82, 117, 114, 122, 72, 118, 57, 69, 90, 74, 57, 121, 90, 76, 56, 110, 97, 102, 98, 47, 84, 49, 70, 97, 111, 80, 68, 107, 117, 74, 102, 77, 43, 105, 80, 115, 48, 106, 56, 120, 110, 83, 55, 84, 97, 85, 47, 103, 69, 75, 48, 119, 67, 120, 101, 68, 89, 82, 89, 116, 74, 120, 57, 106, 52, 104, 85, 81, 113, 55, 112, 65, 117, 47, 84, 50, 121, 87, 121, 48, 118, 106, 99, 85, 72, 107, 105, 57, 53, 50, 90, 78, 98, 88, 110, 88, 120, 66, 56, 109, 56, 112, 86, 53, 120, 57, 69, 49, 115, 102, 76, 106, 53, 77, 90, 69, 103, 112, 85, 50, 88, 86, 56, 82, 72, 114, 86, 118, 87, 110, 105, 67, 106, 115, 102, 54, 118, 103, 120, 109, 82, 55, 43, 75, 116, 119, 73, 98, 77, 106, 97, 104, 105, 116, 85, 71, 116, 72, 101, 116, 49, 87, 100, 76, 43, 56, 77, 109, 100, 76, 50, 57, 105, 81, 74, 67, 51, 55, 112, 68, 88, 105, 114, 105, 114, 49, 78, 105, 98, 120, 75, 75, 104, 70, 89, 82, 117, 74, 51, 120, 87, 57, 79, 48, 114, 57, 43, 86, 110, 104, 56, 100, 105, 113, 98, 66, 117, 88, 113, 68, 98, 89, 82, 47, 77, 83, 111, 72, 118, 115, 99, 79, 67, 109, 50, 116, 57, 53, 100, 78, 53, 87, 66, 100, 82, 85, 111, 68, 55, 89, 67, 71, 47, 90, 72, 87, 99, 55, 89, 112, 118, 47, 120, 47, 97, 108, 52, 102, 107, 66, 50, 108, 90, 108, 89, 104, 86, 87, 72, 120, 106, 97, 111, 101, 70, 57, 106, 69, 80, 73, 48, 103, 65, 78, 53, 88, 115, 118, 85, 73, 54, 104, 98, 122, 69, 122, 87, 77, 115, 78, 87, 47, 49, 111, 114, 107, 78, 79, 110, 108, 115, 107, 97, 108, 103, 109, 112, 73, 52, 66, 50, 114, 109, 52, 71, 99, 55, 76, 78, 117, 105, 43, 77, 117, 77, 66, 114, 112, 110, 66, 118, 76, 107, 98, 89, 88, 57, 101, 120, 101, 57, 103, 56, 116, 117, 55, 119, 76, 116, 55, 83, 99, 79, 106, 68, 99, 76, 57, 57, 111, 79, 121, 82, 56, 57, 77, 104, 57, 76, 56, 114, 100, 52, 43, 52, 51, 43, 74, 81, 121, 82, 54, 116, 115, 73, 102, 99, 80, 74, 111, 54, 84, 54, 70, 120, 72, 102, 49, 49, 100, 47, 77, 71, 97, 121, 74, 105, 43, 83, 87, 99, 116, 47, 117, 104, 118, 118, 117, 97, 48, 111, 79, 104, 43, 122, 88, 78, 73, 97, 85, 122, 103, 111, 66, 109, 117, 49, 88, 85, 76, 106, 107, 112, 117, 65, 48, 71, 104, 122, 99, 116, 102, 51, 48, 106, 98, 89, 49, 65, 79, 77, 52, 57, 113, 98, 77, 90, 82, 89, 83, 57, 65, 43, 48, 83, 49, 72, 114, 72, 80, 110, 119, 82, 118, 112, 81, 89, 47, 83, 106, 52, 120, 75, 80, 110, 48, 103, 100, 112, 118, 47, 43, 105, 84, 98, 75, 74, 98, 56, 122, 107, 80, 67, 52, 47, 57, 97, 102, 48, 74, 118, 101, 115, 97, 43, 71, 68, 71, 48, 47, 105, 119, 51, 84, 115, 119, 101, 110, 77, 104, 113, 108, 104, 55, 66, 77, 57, 77, 87, 53, 116, 120, 112, 101, 98, 108, 115, 66, 121, 120, 52, 87, 110, 74, 47, 111, 72, 118, 54, 99, 99, 48, 100, 109, 77, 55, 116, 115, 86, 51, 54, 108, 89, 107, 67, 84, 85, 88, 69, 102, 47, 48, 101, 75, 108, 110, 102, 105, 118, 110, 78, 48, 103, 49, 103, 43, 106, 47, 76, 107, 57, 101, 116, 47, 117, 111, 97, 54, 84, 70, 67, 87, 48, 72, 103, 119, 70, 79, 73, 86, 70, 117, 109, 69, 89, 100, 84, 54, 55, 53, 80, 102, 117, 84, 114, 89, 79, 53, 111, 56, 90, 114, 87, 69, 73, 72, 116, 118, 50, 67, 116, 108, 114, 118, 57, 74, 51, 84, 114, 115, 108, 68, 47, 105, 75, 69, 119, 116, 105, 112, 71, 72, 116, 110, 48, 86, 97, 107, 56, 66, 57, 119, 76, 76, 43, 107, 122, 43, 67, 73, 81, 47, 86, 71, 52, 75, 74, 112, 88, 106, 120, 56, 56, 67, 101, 67, 67, 52, 88, 97, 71, 105, 116, 69, 100, 106, 65, 65, 65, 34 }, "F", "Brown", 58f }
                });

            migrationBuilder.InsertData(
                table: "DataSource",
                columns: new[] { "IdSource", "Model", "Precision", "Type" },
                values: new object[,]
                {
                    { 1, "Garmin", 0.5f, "Smartwatch" },
                    { 2, "Polar", 0.5f, "Smartwatch" },
                    { 3, "Suunto", 0.5f, "Smartwatch" },
                    { 4, "Fitbit", 0.5f, "Smartwatch" },
                    { 5, "Apple Watch", 0.5f, "Smartwatch" }
                });

            migrationBuilder.InsertData(
                table: "Activity",
                columns: new[] { "IdActivity", "AthleteId", "Average", "AverageTemperature", "DataSourceId", "Date", "EffortFelt", "EndTime", "HasAutoPause", "Maximum", "Minimum", "StandardDeviation", "StartTime", "Type", "Variability", "Variance" },
                values: new object[,]
                {
                    { 1, 1, 0.5f, 20f, 1, new DateOnly(2023, 1, 10), 5, new TimeOnly(14, 0, 22), false, 0, 0, 0.5f, new TimeOnly(13, 0, 34), "Running", 0.5f, 0.5f },
                    { 3, 1, 0.5f, 20f, 1, new DateOnly(2023, 12, 10), 5, new TimeOnly(15, 2, 22), false, 0, 0, 0.5f, new TimeOnly(13, 30, 34), "Swimming", 0.5f, 0.5f },
                    { 5, 4, 0.5f, 20f, 4, new DateOnly(2024, 1, 12), 5, new TimeOnly(9, 0, 22), false, 0, 0, 0.5f, new TimeOnly(7, 45, 34), "Hiking", 0.5f, 0.5f },
                    { 6, 4, 0.5f, 20f, 4, new DateOnly(2024, 1, 27), 5, new TimeOnly(14, 0, 22), false, 0, 0, 0.5f, new TimeOnly(13, 30, 1), "Climbing", 0.5f, 0.5f },
                    { 7, 3, 0.5f, 20f, 5, new DateOnly(2024, 2, 22), 5, new TimeOnly(23, 50, 58), false, 0, 0, 0.5f, new TimeOnly(22, 0, 34), "Yoga", 0.5f, 0.5f }
                });

            migrationBuilder.InsertData(
                table: "Athlete",
                columns: new[] { "IdAthlete", "DataSourceId", "DateOfBirth", "Email", "FirstName", "IsCoach", "LastName", "Length", "Password", "ProfilPicture", "Sexe", "Username", "Weight" },
                values: new object[,]
                {
                    { 2, 1, new DateOnly(1995, 1, 1), "jane.smith@exemple.com", "Jane", false, "Smith", 1.6499999999999999, "secure456", new byte[] { 34, 85, 107, 108, 71, 82, 116, 119, 68, 65, 65, 66, 88, 82, 85, 74, 81, 86, 108, 65, 52, 73, 78, 65, 68, 65, 65, 65, 119, 69, 65, 67, 100, 65, 83, 111, 113, 65, 67, 111, 65, 65, 77, 65, 83, 74, 90, 103, 67, 100, 77, 111, 83, 67, 122, 54, 53, 53, 110, 100, 85, 52, 88, 88, 65, 80, 50, 121, 88, 73, 103, 101, 53, 110, 101, 77, 47, 81, 100, 54, 87, 67, 102, 79, 56, 101, 118, 111, 106, 50, 83, 48, 65, 47, 112, 55, 43, 102, 48, 65, 110, 56, 53, 99, 66, 120, 108, 76, 68, 103, 80, 67, 56, 106, 79, 47, 48, 110, 115, 108, 47, 49, 51, 47, 79, 56, 118, 118, 122, 106, 55, 65, 102, 56, 115, 47, 112, 51, 47, 72, 52, 70, 85, 54, 116, 100, 52, 77, 67, 119, 113, 50, 51, 122, 49, 72, 50, 117, 122, 111, 75, 73, 88, 97, 113, 74, 110, 105, 80, 73, 47, 98, 82, 77, 102, 56, 113, 122, 118, 48, 90, 112, 43, 72, 69, 49, 82, 67, 66, 119, 53, 87, 81, 49, 106, 47, 74, 111, 118, 100, 77, 49, 70, 83, 53, 50, 43, 81, 99, 97, 65, 65, 65, 47, 118, 47, 43, 78, 120, 85, 52, 68, 112, 80, 107, 51, 43, 120, 81, 80, 87, 55, 116, 99, 109, 85, 82, 83, 111, 57, 118, 67, 52, 113, 99, 43, 88, 77, 120, 78, 86, 66, 122, 69, 77, 53, 69, 56, 97, 99, 116, 68, 122, 57, 56, 103, 109, 119, 84, 88, 103, 68, 54, 50, 101, 57, 69, 109, 71, 47, 101, 114, 118, 100, 100, 50, 111, 118, 70, 70, 83, 117, 120, 89, 112, 112, 87, 108, 47, 119, 116, 97, 88, 51, 114, 107, 110, 48, 120, 114, 116, 56, 113, 79, 113, 108, 47, 53, 73, 50, 106, 102, 76, 79, 110, 67, 85, 48, 107, 65, 76, 76, 99, 87, 52, 70, 47, 119, 84, 106, 85, 49, 48, 113, 115, 120, 90, 88, 87, 57, 102, 120, 97, 117, 67, 54, 79, 80, 86, 82, 70, 50, 56, 115, 99, 57, 52, 86, 57, 111, 99, 109, 111, 83, 87, 121, 43, 115, 102, 54, 106, 87, 51, 118, 89, 107, 86, 79, 104, 43, 103, 69, 47, 82, 69, 48, 76, 54, 98, 50, 100, 51, 111, 70, 121, 72, 109, 107, 82, 74, 110, 102, 89, 119, 71, 56, 111, 51, 112, 54, 102, 118, 57, 112, 105, 118, 78, 70, 53, 97, 111, 112, 73, 66, 122, 70, 110, 106, 122, 119, 98, 47, 86, 113, 83, 113, 51, 47, 98, 43, 77, 87, 75, 70, 109, 106, 114, 56, 84, 49, 113, 101, 52, 47, 102, 73, 84, 111, 50, 118, 66, 87, 69, 113, 68, 121, 111, 103, 86, 51, 90, 86, 71, 110, 68, 86, 105, 50, 68, 98, 105, 69, 70, 86, 83, 85, 114, 50, 101, 88, 84, 78, 90, 81, 57, 86, 47, 68, 57, 81, 67, 47, 43, 118, 67, 82, 53, 84, 71, 121, 88, 57, 81, 79, 86, 66, 103, 116, 65, 89, 116, 109, 47, 90, 84, 73, 119, 122, 80, 69, 89, 66, 57, 78, 114, 86, 49, 78, 101, 79, 49, 47, 115, 65, 122, 55, 56, 117, 48, 116, 87, 53, 57, 114, 48, 73, 43, 83, 79, 53, 74, 103, 109, 51, 66, 57, 105, 49, 116, 111, 82, 117, 114, 122, 72, 118, 57, 69, 90, 74, 57, 121, 90, 76, 56, 110, 97, 102, 98, 47, 84, 49, 70, 97, 111, 80, 68, 107, 117, 74, 102, 77, 43, 105, 80, 115, 48, 106, 56, 120, 110, 83, 55, 84, 97, 85, 47, 103, 69, 75, 48, 119, 67, 120, 101, 68, 89, 82, 89, 116, 74, 120, 57, 106, 52, 104, 85, 81, 113, 55, 112, 65, 117, 47, 84, 50, 121, 87, 121, 48, 118, 106, 99, 85, 72, 107, 105, 57, 53, 50, 90, 78, 98, 88, 110, 88, 120, 66, 56, 109, 56, 112, 86, 53, 120, 57, 69, 49, 115, 102, 76, 106, 53, 77, 90, 69, 103, 112, 85, 50, 88, 86, 56, 82, 72, 114, 86, 118, 87, 110, 105, 67, 106, 115, 102, 54, 118, 103, 120, 109, 82, 55, 43, 75, 116, 119, 73, 98, 77, 106, 97, 104, 105, 116, 85, 71, 116, 72, 101, 116, 49, 87, 100, 76, 43, 56, 77, 109, 100, 76, 50, 57, 105, 81, 74, 67, 51, 55, 112, 68, 88, 105, 114, 105, 114, 49, 78, 105, 98, 120, 75, 75, 104, 70, 89, 82, 117, 74, 51, 120, 87, 57, 79, 48, 114, 57, 43, 86, 110, 104, 56, 100, 105, 113, 98, 66, 117, 88, 113, 68, 98, 89, 82, 47, 77, 83, 111, 72, 118, 115, 99, 79, 67, 109, 50, 116, 57, 53, 100, 78, 53, 87, 66, 100, 82, 85, 111, 68, 55, 89, 67, 71, 47, 90, 72, 87, 99, 55, 89, 112, 118, 47, 120, 47, 97, 108, 52, 102, 107, 66, 50, 108, 90, 108, 89, 104, 86, 87, 72, 120, 106, 97, 111, 101, 70, 57, 106, 69, 80, 73, 48, 103, 65, 78, 53, 88, 115, 118, 85, 73, 54, 104, 98, 122, 69, 122, 87, 77, 115, 78, 87, 47, 49, 111, 114, 107, 78, 79, 110, 108, 115, 107, 97, 108, 103, 109, 112, 73, 52, 66, 50, 114, 109, 52, 71, 99, 55, 76, 78, 117, 105, 43, 77, 117, 77, 66, 114, 112, 110, 66, 118, 76, 107, 98, 89, 88, 57, 101, 120, 101, 57, 103, 56, 116, 117, 55, 119, 76, 116, 55, 83, 99, 79, 106, 68, 99, 76, 57, 57, 111, 79, 121, 82, 56, 57, 77, 104, 57, 76, 56, 114, 100, 52, 43, 52, 51, 43, 74, 81, 121, 82, 54, 116, 115, 73, 102, 99, 80, 74, 111, 54, 84, 54, 70, 120, 72, 102, 49, 49, 100, 47, 77, 71, 97, 121, 74, 105, 43, 83, 87, 99, 116, 47, 117, 104, 118, 118, 117, 97, 48, 111, 79, 104, 43, 122, 88, 78, 73, 97, 85, 122, 103, 111, 66, 109, 117, 49, 88, 85, 76, 106, 107, 112, 117, 65, 48, 71, 104, 122, 99, 116, 102, 51, 48, 106, 98, 89, 49, 65, 79, 77, 52, 57, 113, 98, 77, 90, 82, 89, 83, 57, 65, 43, 48, 83, 49, 72, 114, 72, 80, 110, 119, 82, 118, 112, 81, 89, 47, 83, 106, 52, 120, 75, 80, 110, 48, 103, 100, 112, 118, 47, 43, 105, 84, 98, 75, 74, 98, 56, 122, 107, 80, 67, 52, 47, 57, 97, 102, 48, 74, 118, 101, 115, 97, 43, 71, 68, 71, 48, 47, 105, 119, 51, 84, 115, 119, 101, 110, 77, 104, 113, 108, 104, 55, 66, 77, 57, 77, 87, 53, 116, 120, 112, 101, 98, 108, 115, 66, 121, 120, 52, 87, 110, 74, 47, 111, 72, 118, 54, 99, 99, 48, 100, 109, 77, 55, 116, 115, 86, 51, 54, 108, 89, 107, 67, 84, 85, 88, 69, 102, 47, 48, 101, 75, 108, 110, 102, 105, 118, 110, 78, 48, 103, 49, 103, 43, 106, 47, 76, 107, 57, 101, 116, 47, 117, 111, 97, 54, 84, 70, 67, 87, 48, 72, 103, 119, 70, 79, 73, 86, 70, 117, 109, 69, 89, 100, 84, 54, 55, 53, 80, 102, 117, 84, 114, 89, 79, 53, 111, 56, 90, 114, 87, 69, 73, 72, 116, 118, 50, 67, 116, 108, 114, 118, 57, 74, 51, 84, 114, 115, 108, 68, 47, 105, 75, 69, 119, 116, 105, 112, 71, 72, 116, 110, 48, 86, 97, 107, 56, 66, 57, 119, 76, 76, 43, 107, 122, 43, 67, 73, 81, 47, 86, 71, 52, 75, 74, 112, 88, 106, 120, 56, 56, 67, 101, 67, 67, 52, 88, 97, 71, 105, 116, 69, 100, 106, 65, 65, 65, 34 }, "F", "Smith", 60f },
                    { 5, 3, new DateOnly(1991, 1, 1), "bruce.lee@example.com", "Bruce", false, "Lee", 2.0, "hello321", new byte[] { 34, 85, 107, 108, 71, 82, 116, 119, 68, 65, 65, 66, 88, 82, 85, 74, 81, 86, 108, 65, 52, 73, 78, 65, 68, 65, 65, 65, 119, 69, 65, 67, 100, 65, 83, 111, 113, 65, 67, 111, 65, 65, 77, 65, 83, 74, 90, 103, 67, 100, 77, 111, 83, 67, 122, 54, 53, 53, 110, 100, 85, 52, 88, 88, 65, 80, 50, 121, 88, 73, 103, 101, 53, 110, 101, 77, 47, 81, 100, 54, 87, 67, 102, 79, 56, 101, 118, 111, 106, 50, 83, 48, 65, 47, 112, 55, 43, 102, 48, 65, 110, 56, 53, 99, 66, 120, 108, 76, 68, 103, 80, 67, 56, 106, 79, 47, 48, 110, 115, 108, 47, 49, 51, 47, 79, 56, 118, 118, 122, 106, 55, 65, 102, 56, 115, 47, 112, 51, 47, 72, 52, 70, 85, 54, 116, 100, 52, 77, 67, 119, 113, 50, 51, 122, 49, 72, 50, 117, 122, 111, 75, 73, 88, 97, 113, 74, 110, 105, 80, 73, 47, 98, 82, 77, 102, 56, 113, 122, 118, 48, 90, 112, 43, 72, 69, 49, 82, 67, 66, 119, 53, 87, 81, 49, 106, 47, 74, 111, 118, 100, 77, 49, 70, 83, 53, 50, 43, 81, 99, 97, 65, 65, 65, 47, 118, 47, 43, 78, 120, 85, 52, 68, 112, 80, 107, 51, 43, 120, 81, 80, 87, 55, 116, 99, 109, 85, 82, 83, 111, 57, 118, 67, 52, 113, 99, 43, 88, 77, 120, 78, 86, 66, 122, 69, 77, 53, 69, 56, 97, 99, 116, 68, 122, 57, 56, 103, 109, 119, 84, 88, 103, 68, 54, 50, 101, 57, 69, 109, 71, 47, 101, 114, 118, 100, 100, 50, 111, 118, 70, 70, 83, 117, 120, 89, 112, 112, 87, 108, 47, 119, 116, 97, 88, 51, 114, 107, 110, 48, 120, 114, 116, 56, 113, 79, 113, 108, 47, 53, 73, 50, 106, 102, 76, 79, 110, 67, 85, 48, 107, 65, 76, 76, 99, 87, 52, 70, 47, 119, 84, 106, 85, 49, 48, 113, 115, 120, 90, 88, 87, 57, 102, 120, 97, 117, 67, 54, 79, 80, 86, 82, 70, 50, 56, 115, 99, 57, 52, 86, 57, 111, 99, 109, 111, 83, 87, 121, 43, 115, 102, 54, 106, 87, 51, 118, 89, 107, 86, 79, 104, 43, 103, 69, 47, 82, 69, 48, 76, 54, 98, 50, 100, 51, 111, 70, 121, 72, 109, 107, 82, 74, 110, 102, 89, 119, 71, 56, 111, 51, 112, 54, 102, 118, 57, 112, 105, 118, 78, 70, 53, 97, 111, 112, 73, 66, 122, 70, 110, 106, 122, 119, 98, 47, 86, 113, 83, 113, 51, 47, 98, 43, 77, 87, 75, 70, 109, 106, 114, 56, 84, 49, 113, 101, 52, 47, 102, 73, 84, 111, 50, 118, 66, 87, 69, 113, 68, 121, 111, 103, 86, 51, 90, 86, 71, 110, 68, 86, 105, 50, 68, 98, 105, 69, 70, 86, 83, 85, 114, 50, 101, 88, 84, 78, 90, 81, 57, 86, 47, 68, 57, 81, 67, 47, 43, 118, 67, 82, 53, 84, 71, 121, 88, 57, 81, 79, 86, 66, 103, 116, 65, 89, 116, 109, 47, 90, 84, 73, 119, 122, 80, 69, 89, 66, 57, 78, 114, 86, 49, 78, 101, 79, 49, 47, 115, 65, 122, 55, 56, 117, 48, 116, 87, 53, 57, 114, 48, 73, 43, 83, 79, 53, 74, 103, 109, 51, 66, 57, 105, 49, 116, 111, 82, 117, 114, 122, 72, 118, 57, 69, 90, 74, 57, 121, 90, 76, 56, 110, 97, 102, 98, 47, 84, 49, 70, 97, 111, 80, 68, 107, 117, 74, 102, 77, 43, 105, 80, 115, 48, 106, 56, 120, 110, 83, 55, 84, 97, 85, 47, 103, 69, 75, 48, 119, 67, 120, 101, 68, 89, 82, 89, 116, 74, 120, 57, 106, 52, 104, 85, 81, 113, 55, 112, 65, 117, 47, 84, 50, 121, 87, 121, 48, 118, 106, 99, 85, 72, 107, 105, 57, 53, 50, 90, 78, 98, 88, 110, 88, 120, 66, 56, 109, 56, 112, 86, 53, 120, 57, 69, 49, 115, 102, 76, 106, 53, 77, 90, 69, 103, 112, 85, 50, 88, 86, 56, 82, 72, 114, 86, 118, 87, 110, 105, 67, 106, 115, 102, 54, 118, 103, 120, 109, 82, 55, 43, 75, 116, 119, 73, 98, 77, 106, 97, 104, 105, 116, 85, 71, 116, 72, 101, 116, 49, 87, 100, 76, 43, 56, 77, 109, 100, 76, 50, 57, 105, 81, 74, 67, 51, 55, 112, 68, 88, 105, 114, 105, 114, 49, 78, 105, 98, 120, 75, 75, 104, 70, 89, 82, 117, 74, 51, 120, 87, 57, 79, 48, 114, 57, 43, 86, 110, 104, 56, 100, 105, 113, 98, 66, 117, 88, 113, 68, 98, 89, 82, 47, 77, 83, 111, 72, 118, 115, 99, 79, 67, 109, 50, 116, 57, 53, 100, 78, 53, 87, 66, 100, 82, 85, 111, 68, 55, 89, 67, 71, 47, 90, 72, 87, 99, 55, 89, 112, 118, 47, 120, 47, 97, 108, 52, 102, 107, 66, 50, 108, 90, 108, 89, 104, 86, 87, 72, 120, 106, 97, 111, 101, 70, 57, 106, 69, 80, 73, 48, 103, 65, 78, 53, 88, 115, 118, 85, 73, 54, 104, 98, 122, 69, 122, 87, 77, 115, 78, 87, 47, 49, 111, 114, 107, 78, 79, 110, 108, 115, 107, 97, 108, 103, 109, 112, 73, 52, 66, 50, 114, 109, 52, 71, 99, 55, 76, 78, 117, 105, 43, 77, 117, 77, 66, 114, 112, 110, 66, 118, 76, 107, 98, 89, 88, 57, 101, 120, 101, 57, 103, 56, 116, 117, 55, 119, 76, 116, 55, 83, 99, 79, 106, 68, 99, 76, 57, 57, 111, 79, 121, 82, 56, 57, 77, 104, 57, 76, 56, 114, 100, 52, 43, 52, 51, 43, 74, 81, 121, 82, 54, 116, 115, 73, 102, 99, 80, 74, 111, 54, 84, 54, 70, 120, 72, 102, 49, 49, 100, 47, 77, 71, 97, 121, 74, 105, 43, 83, 87, 99, 116, 47, 117, 104, 118, 118, 117, 97, 48, 111, 79, 104, 43, 122, 88, 78, 73, 97, 85, 122, 103, 111, 66, 109, 117, 49, 88, 85, 76, 106, 107, 112, 117, 65, 48, 71, 104, 122, 99, 116, 102, 51, 48, 106, 98, 89, 49, 65, 79, 77, 52, 57, 113, 98, 77, 90, 82, 89, 83, 57, 65, 43, 48, 83, 49, 72, 114, 72, 80, 110, 119, 82, 118, 112, 81, 89, 47, 83, 106, 52, 120, 75, 80, 110, 48, 103, 100, 112, 118, 47, 43, 105, 84, 98, 75, 74, 98, 56, 122, 107, 80, 67, 52, 47, 57, 97, 102, 48, 74, 118, 101, 115, 97, 43, 71, 68, 71, 48, 47, 105, 119, 51, 84, 115, 119, 101, 110, 77, 104, 113, 108, 104, 55, 66, 77, 57, 77, 87, 53, 116, 120, 112, 101, 98, 108, 115, 66, 121, 120, 52, 87, 110, 74, 47, 111, 72, 118, 54, 99, 99, 48, 100, 109, 77, 55, 116, 115, 86, 51, 54, 108, 89, 107, 67, 84, 85, 88, 69, 102, 47, 48, 101, 75, 108, 110, 102, 105, 118, 110, 78, 48, 103, 49, 103, 43, 106, 47, 76, 107, 57, 101, 116, 47, 117, 111, 97, 54, 84, 70, 67, 87, 48, 72, 103, 119, 70, 79, 73, 86, 70, 117, 109, 69, 89, 100, 84, 54, 55, 53, 80, 102, 117, 84, 114, 89, 79, 53, 111, 56, 90, 114, 87, 69, 73, 72, 116, 118, 50, 67, 116, 108, 114, 118, 57, 74, 51, 84, 114, 115, 108, 68, 47, 105, 75, 69, 119, 116, 105, 112, 71, 72, 116, 110, 48, 86, 97, 107, 56, 66, 57, 119, 76, 76, 43, 107, 122, 43, 67, 73, 81, 47, 86, 71, 52, 75, 74, 112, 88, 106, 120, 56, 56, 67, 101, 67, 67, 52, 88, 97, 71, 105, 116, 69, 100, 106, 65, 65, 65, 34 }, "M", "Lee", 90f }
                });

            migrationBuilder.InsertData(
                table: "FriendshipEntity",
                columns: new[] { "FollowerId", "FollowingId", "StartDate" },
                values: new object[,]
                {
                    { 1, 3, new DateTime(1, 1, 1, 0, 0, 0, 0, DateTimeKind.Unspecified) },
                    { 1, 4, new DateTime(1, 1, 1, 0, 0, 0, 0, DateTimeKind.Unspecified) }
                });

            migrationBuilder.InsertData(
                table: "Notification",
                columns: new[] { "IdNotif", "Date", "Message", "SenderId", "Statut", "Urgence" },
                values: new object[,]
                {
                    { 1, new DateTime(2023, 12, 25, 13, 0, 40, 0, DateTimeKind.Unspecified), "You have a new activity to check", 1, true, "A" },
                    { 3, new DateTime(2023, 12, 26, 16, 10, 4, 0, DateTimeKind.Unspecified), "You have a new heart rate to check", 3, true, "2" },
                    { 4, new DateTime(2024, 1, 12, 9, 30, 50, 0, DateTimeKind.Unspecified), "You have a new data source to check", 4, false, "1" }
                });

            migrationBuilder.InsertData(
                table: "Statistic",
                columns: new[] { "IdStatistic", "AthleteId", "AverageCaloriesBurned", "AverageHeartRate", "Date", "MaximumHeartRate", "Weight" },
                values: new object[,]
                {
                    { 1, 1, 500.0, 120.0, new DateOnly(2021, 12, 12), 180.0, 75f },
                    { 3, 1, 550.0, 125.0, new DateOnly(2022, 12, 30), 185.0, 68f },
                    { 4, 3, 650.0, 135.0, new DateOnly(2023, 2, 20), 195.0, 58f },
                    { 5, 4, 450.0, 110.0, new DateOnly(2024, 1, 10), 170.0, 90f }
                });

            migrationBuilder.InsertData(
                table: "Training",
                columns: new[] { "IdTraining", "CoachId", "Date", "Description", "FeedBack", "Latitude", "Longitude" },
                values: new object[,]
                {
                    { 1, 1, new DateOnly(2024, 1, 19), "Running", "Good", 48.8566f, 2.3522f },
                    { 3, 4, new DateOnly(2024, 2, 21), null, "Good", 48.8566f, 2.3522f },
                    { 4, 3, new DateOnly(2024, 2, 22), "Running", "Good", 48.8566f, 2.3522f },
                    { 5, 1, new DateOnly(2024, 2, 23), "Cycling", null, 48.8566f, 2.3522f }
                });

            migrationBuilder.InsertData(
                table: "Activity",
                columns: new[] { "IdActivity", "AthleteId", "Average", "AverageTemperature", "DataSourceId", "Date", "EffortFelt", "EndTime", "HasAutoPause", "Maximum", "Minimum", "StandardDeviation", "StartTime", "Type", "Variability", "Variance" },
                values: new object[,]
                {
                    { 2, 2, 0.5f, 20f, 2, new DateOnly(2023, 1, 25), 5, new TimeOnly(14, 0, 22), false, 0, 0, 0.5f, new TimeOnly(13, 4, 34), "Cycling", 0.5f, 0.5f },
                    { 4, 5, 0.5f, 20f, 3, new DateOnly(2024, 1, 2), 5, new TimeOnly(16, 1, 55), false, 0, 0, 0.5f, new TimeOnly(15, 0, 0), "Walking", 0.5f, 0.5f }
                });

            migrationBuilder.InsertData(
                table: "FriendshipEntity",
                columns: new[] { "FollowerId", "FollowingId", "StartDate" },
                values: new object[,]
                {
                    { 2, 1, new DateTime(1, 1, 1, 0, 0, 0, 0, DateTimeKind.Unspecified) },
                    { 1, 2, new DateTime(1, 1, 1, 0, 0, 0, 0, DateTimeKind.Unspecified) },
                    { 2, 3, new DateTime(1, 1, 1, 0, 0, 0, 0, DateTimeKind.Unspecified) },
                    { 1, 5, new DateTime(1, 1, 1, 0, 0, 0, 0, DateTimeKind.Unspecified) }
                });

            migrationBuilder.InsertData(
                table: "HeartRate",
                columns: new[] { "IdHeartRate", "ActivityId", "Altitude", "Bpm", "Latitude", "Longitude", "Temperature", "Time" },
                values: new object[,]
                {
                    { 1, 1, 0.0, 60, 66f, 35f, 20f, new TimeOnly(13, 0, 30) },
                    { 3, 1, 11.0, 71, 66f, 36f, 20f, new TimeOnly(13, 0, 32) }
                });

            migrationBuilder.InsertData(
                table: "Notification",
                columns: new[] { "IdNotif", "Date", "Message", "SenderId", "Statut", "Urgence" },
                values: new object[,]
                {
                    { 2, new DateTime(2023, 12, 26, 13, 10, 40, 0, DateTimeKind.Unspecified), "You have a new athlete to check", 2, false, "3" },
                    { 5, new DateTime(2024, 2, 22, 12, 10, 0, 0, DateTimeKind.Unspecified), "You have a new notification to check", 5, true, "3" }
                });

            migrationBuilder.InsertData(
                table: "Statistic",
                columns: new[] { "IdStatistic", "AthleteId", "AverageCaloriesBurned", "AverageHeartRate", "Date", "MaximumHeartRate", "Weight" },
                values: new object[] { 2, 2, 600.0, 130.0, new DateOnly(2021, 1, 11), 190.0, 60f });

            migrationBuilder.InsertData(
                table: "Training",
                columns: new[] { "IdTraining", "CoachId", "Date", "Description", "FeedBack", "Latitude", "Longitude" },
                values: new object[] { 2, 5, new DateOnly(2024, 2, 20), "Cycling", null, 48.8566f, 2.3522f });

            migrationBuilder.InsertData(
                table: "HeartRate",
                columns: new[] { "IdHeartRate", "ActivityId", "Altitude", "Bpm", "Latitude", "Longitude", "Temperature", "Time" },
                values: new object[,]
                {
                    { 2, 2, 10.0, 65, 67f, 35f, 20.5f, new TimeOnly(13, 0, 31) },
                    { 4, 2, 12.0, 75, 67f, 36f, 20.5f, new TimeOnly(13, 0, 33) },
                    { 5, 4, 13.0, 80, 66f, 37f, 20f, new TimeOnly(13, 0, 34) }
                });

            migrationBuilder.CreateIndex(
                name: "IX_Activity_AthleteId",
                table: "Activity",
                column: "AthleteId");

            migrationBuilder.CreateIndex(
                name: "IX_Activity_DataSourceId",
                table: "Activity",
                column: "DataSourceId");

            migrationBuilder.CreateIndex(
                name: "IX_Athlete_DataSourceId",
                table: "Athlete",
                column: "DataSourceId");

            migrationBuilder.CreateIndex(
                name: "IX_AthleteEntityNotificationEntity_ReceiversIdAthlete",
                table: "AthleteEntityNotificationEntity",
                column: "ReceiversIdAthlete");

            migrationBuilder.CreateIndex(
                name: "IX_AthleteEntityTrainingEntity_TrainingsAthleteIdTraining",
                table: "AthleteEntityTrainingEntity",
                column: "TrainingsAthleteIdTraining");

            migrationBuilder.CreateIndex(
                name: "IX_FriendshipEntity_FollowerId",
                table: "FriendshipEntity",
                column: "FollowerId");

            migrationBuilder.CreateIndex(
                name: "IX_HeartRate_ActivityId",
                table: "HeartRate",
                column: "ActivityId");

            migrationBuilder.CreateIndex(
                name: "IX_Notification_SenderId",
                table: "Notification",
                column: "SenderId");

            migrationBuilder.CreateIndex(
                name: "IX_Statistic_AthleteId",
                table: "Statistic",
                column: "AthleteId");

            migrationBuilder.CreateIndex(
                name: "IX_Training_CoachId",
                table: "Training",
                column: "CoachId");
        }

        /// <inheritdoc />
        protected override void Down(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.DropTable(
                name: "AthleteEntityNotificationEntity");

            migrationBuilder.DropTable(
                name: "AthleteEntityTrainingEntity");

            migrationBuilder.DropTable(
                name: "FriendshipEntity");

            migrationBuilder.DropTable(
                name: "HeartRate");

            migrationBuilder.DropTable(
                name: "Statistic");

            migrationBuilder.DropTable(
                name: "Notification");

            migrationBuilder.DropTable(
                name: "Training");

            migrationBuilder.DropTable(
                name: "Activity");

            migrationBuilder.DropTable(
                name: "Athlete");

            migrationBuilder.DropTable(
                name: "DataSource");
        }
    }
}
